@@ -1,7 +1,7 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: dump_jp2.py 545d0423e15cc28a5aca3a9852fab80b80601162 2018-12-12 11:49:36 +1300 Craig de Stigter $
+#  $Id: dump_jp2.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
 #
 #  Project:  GDAL
 #  Purpose:  Dump JPEG2000 file structure
@@ -200,7 +200,10 @@ def main():
                 return 1
     else:
         s = gdal.GetJPEG2000StructureAsString(filename, ['ALL=YES'])
-        print(s)
+        if sys.version_info >= (3,0,0):
+            print(s)
+        else:
+            print(s.encode('UTF-8'))
 
     return 0
 
