@@ -1,6 +1,6 @@
-#!/usr/local/bin/python3.7
+#!/usr/local/bin/python3.8
 ###############################################################################
-# $Id: gdal_rmdir.py ca5d0820bd60c7e33031b99a61dfe01573ab5ec1 2018-04-25 18:43:11 +1000 Ben Elliston $
+# $Id: gdal_rmdir.py 8a702a1d0f3574aa6a86b74e7b19ab05058ee032 2020-02-25 16:06:12 +0100 Even Rouault $
 #
 #  Project:  GDAL samples
 #  Purpose:  Delete a virtual directory
@@ -41,13 +41,16 @@ def Usage():
 def gdal_rm(argv, progress=None):
     # pylint: disable=unused-argument
     filename = None
+    recursive = False
 
     argv = gdal.GeneralCmdLineProcessor(argv)
     if argv is None:
         return -1
 
     for i in range(1, len(argv)):
-        if filename is None:
+        if argv[i] == '-r':
+            recursive = True
+        elif filename is None:
             filename = argv[i]
         elif argv[i][0] == '-':
             print('Unexpected option : %s' % argv[i])
@@ -59,7 +62,10 @@ def gdal_rm(argv, progress=None):
     if filename is None:
         return Usage()
 
-    ret = gdal.Rmdir(filename)
+    if recursive:
+        ret = gdal.RmdirRecursive(filename)
+    else:
+        ret = gdal.Rmdir(filename)
     if ret != 0:
         print('Deletion failed')
     return ret
