@@ -1,6 +1,6 @@
 #!/usr/local/bin/python3.8
 # *****************************************************************************
-# $Id: gdalinfo.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+# $Id: gdalinfo.py f8fcfbaa4be8da3655f1c12e9dbf535999340e4e 2020-06-03 22:54:27 +0200 Even Rouault $
 #
 # Project:  GDAL Utilities
 # Purpose:  Python port of Commandline application to list info about a file.
@@ -391,7 +391,7 @@ def main(argv=None):
 
         if bReportHistograms:
 
-            hist = hBand.GetDefaultHistogram(force=True, callback=gdal.TermProgress)
+            hist = hBand.GetDefaultHistogram(force=True, callback=gdal.TermProgress_nocb)
             if hist is not None:
                 dfMin = hist[0]
                 dfMax = hist[1]
