@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: ogr2vrt.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+# $Id: ogr2vrt.py a47364611c193ff14f084bade64d37c7e1443d3b 2020-05-30 17:04:38 +0200 Even Rouault $
 #
 # Project:  OGR Python samples
 # Purpose:  Create OGR VRT from source datasource
@@ -314,6 +314,11 @@ for name in layer_list:
             vrt += ' precision="%d"' % src_fd.GetPrecision()
         if src_fd.IsNullable() == 0:
             vrt += ' nullable="false"'
+        try:
+            if src_fd.IsUnique():
+                vrt += ' unique="true"'
+        except AttributeError: # if run with GDAL < 3.2
+            pass
         vrt += '/>\n'
 
     if feature_count:
