@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 ###############################################################################
-# $Id: ogrupdate.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+# $Id: ogrupdate.py b55a33407a80673ec314b165c82f47dd02e9dc9c 2020-04-27 20:37:55 +0200 Even Rouault $
 #
 # Project:  GDAL/OGR samples
 # Purpose:  Update an existing datasource with features from another one
@@ -195,7 +195,7 @@ def ogrupdate_analyse_args(argv, progress=None, progress_arg=None):
         return 1
 
     if matchfieldname is None and dst_layer.TestCapability(ogr.OLCRandomRead) == 0 and not quiet:
-        print('Warning: target layer does not advertize fast random read capability. Update might be slow')
+        print('Warning: target layer does not advertise fast random read capability. Update might be slow')
 
     if papszSelFields is not None and compare_before_update:
         print('Warning: -select and -compare_before_update are not compatible. Ignoring -compare_before_update')
