@@ -1,7 +1,7 @@
 #!/usr/local/bin/python3.8
 # -*- coding: utf-8 -*-
 # ******************************************************************************
-#  $Id: validate_jp2.py 428d6fbc987332afb0ba6c7b6913390f7386e864 2020-01-17 22:19:28 +0100 Even Rouault $
+#  $Id: validate_jp2.py b55a33407a80673ec314b165c82f47dd02e9dc9c 2020-04-27 20:37:55 +0200 Even Rouault $
 #
 #  Project:  GDAL
 #  Purpose:  Validate JPEG2000 file structure
@@ -537,9 +537,9 @@ def validate(filename, oidoc, inspire_tg, expected_gmljp2, ogc_schemas_location,
                 error_report.EmitError('GENERAL', 'rreq.NSF (=%d) != NSF_found (=%d)' % (NSF, NSF_found))
             if gmljp2_found and not SF67Found:
                 if inspire_tg:
-                    error_report.EmitError('INSPIRE_TG', '"rreq" box does not advertize standard flag 67 whereas GMLJP2 box is present')
+                    error_report.EmitError('INSPIRE_TG', '"rreq" box does not advertise standard flag 67 whereas GMLJP2 box is present')
                 else:
-                    error_report.EmitWarning('GENERAL', '"rreq" box does not advertize standard flag 67 whereas GMLJP2 box is present')
+                    error_report.EmitWarning('GENERAL', '"rreq" box does not advertise standard flag 67 whereas GMLJP2 box is present')
 
             NVF = get_field_val(rreq, 'NVF')
             if NVF is None:
@@ -1163,7 +1163,7 @@ def validate(filename, oidoc, inspire_tg, expected_gmljp2, ogc_schemas_location,
                     error_report.EmitWarning(
                         'GENERAL',
                         'User-defined precincts %d found but '
-                        'SPcod_transformation did not advertize it' % i)
+                        'SPcod_transformation did not advertise it' % i)
                 elif SPcod_Precincts is None and (Scod & 1) != 0:
                     error_report.EmitWarning('GENERAL', 'No user-defined precincts %d defined but SPcod_transformation advertized it' % i)
                 elif SPcod_Precincts is None and inspire_tg:
